pub struct Accelerometer;
Wrapped Accelerometer API.

Implementations

source

impl Accelerometer

source

pub fn enable() -> Option<()>

Enable accelerometer only. By default, the accelerometer is disabled to save (a small amount of) power. To use a peripheral, it must first be enabled via this function. Accelerometer data is not available until the next update cycle after it’s enabled.

Uses setPeripheralsEnabled.

source

pub fn disable() -> Option<()>

Uses setPeripheralsEnabled.

⚠️ Disables all peripherals. Currently it doesn’t matter because there’s just one peripheral - accelerometer.

source

pub fn get() -> Option<(c_float, c_float, c_float)>

Uses getAccelerometer.

Returns (x, y, z) accelerometer data.

source

pub fn get_to( outx: &mut c_float, outy: &mut c_float, outz: &mut c_float ) -> Option<()>

Gets accelerometer data directly to x, y and z.