pub struct Buttons {
    pub current: PDButtons,
    pub pushed: PDButtons,
    pub released: PDButtons,
}
Wrapped Buttons API.

Represents buttons state.

  • current indicates which buttons are currently down.
  • pushed and released reflects which buttons were pushed or released over the previous update cycle.

Note: at the nominal frame rate of 50 ms, fast button presses can be missed if you just poll the instantaneous state.

Fields

current: PDButtons

Indicating which buttons are currently down.

pushed: PDButtons

Reflect which buttons were pushed over the previous update cycle. See struct doc.

released: PDButtons

Reflect which buttons were released over the previous update cycle. See struct doc.

Implementations

source

impl Buttons

source

pub fn get() -> Option<Self>

source

pub fn get_to( current: &mut PDButtons, pushed: &mut PDButtons, released: &mut PDButtons ) -> Option<()>

source

pub fn get_current() -> Option<PDButtons>

Uses getButtonState.

Requests & returns only current part of state, see Self::current

source

pub fn get_pushed() -> Option<PDButtons>

Uses getButtonState.

Requests & returns only current part of state, see Self::pushed

source

pub fn get_released() -> Option<PDButtons>

Uses getButtonState.

Requests & returns only current part of state, see Self::released