pub struct Peripherals<Api = Default>(/* private fields */);
Peripherals

Implementations

source

impl Peripherals<Default>

source

pub fn Default() -> Self

Creates default Peripherals without type parameter requirement.

Uses ZST api::Default.

source

impl Peripherals<Cache>

source

pub fn Cached() -> Self

Creates Peripherals without type parameter requirement.

Uses api::Cache.

source

impl<Api: Default + Api> Peripherals<Api>

source

pub fn new() -> Self

source

impl<Api: Api> Peripherals<Api>

source

pub const fn new_with(api: Api) -> Self

source

impl<Api> Peripherals<Api>where Api: Copy + Api,

source

pub const fn accelerometer(&self) -> Accelerometer<Api>

source

pub const fn buttons(&self) -> Buttons<Api>

source

pub const fn crank(&self) -> Crank<Api>

source

impl<Api: Api> Peripherals<Api>

source

pub fn enable(&self, value: PDPeripherals)

Enables specified peripheral.

Equivalent to sys::ffi::playdate_sys::setPeripheralsEnabled

source

pub fn enable_accelerometer(&self)

By default, the accelerometer is disabled to save (a small amount of) power.

To use a peripheral, it must first be enabled via this function.

Accelerometer data is not available until the next update cycle after it’s enabled.

Equivalent to sys::ffi::playdate_sys::setPeripheralsEnabled

source

pub fn enable_all(&self)

Enables all peripherals.

Equivalent to sys::ffi::playdate_sys::setPeripheralsEnabled

source

pub fn disable_all(&self)

Disables all peripherals.

Equivalent to sys::ffi::playdate_sys::setPeripheralsEnabled

source

impl Peripherals<Default>

source

pub const None: PDPeripherals = PDPeripherals::kNone

source

pub const Accelerometer: PDPeripherals = PDPeripherals::kAccelerometer

source

pub const All: PDPeripherals = PDPeripherals::kAllPeripherals