Struct playdate_controls::peripherals::Buttons
source · pub struct Buttons {
pub current: PDButtons,
pub pushed: PDButtons,
pub released: PDButtons,
}Expand description
Wrapped Buttons API.
Represents buttons state.
currentindicates which buttons are currently down.pushedandreleasedreflects which buttons were pushed or released over the previous update cycle.
Note: at the nominal frame rate of 50 ms, fast button presses can be missed if you just poll the instantaneous state.
Fields
current: PDButtonsIndicating which buttons are currently down.
pushed: PDButtonsReflect which buttons were pushed over the previous update cycle. See struct doc.
released: PDButtonsReflect which buttons were released over the previous update cycle. See struct doc.
Implementations
sourceimpl Buttons
impl Buttons
sourcepub fn get() -> Option<Self>
pub fn get() -> Option<Self>
Uses getButtonState.
sourcepub fn get_to(
current: &mut PDButtons,
pushed: &mut PDButtons,
released: &mut PDButtons
) -> Option<()>
pub fn get_to( current: &mut PDButtons, pushed: &mut PDButtons, released: &mut PDButtons ) -> Option<()>
Uses getButtonState.
sourcepub fn get_current() -> Option<PDButtons>
pub fn get_current() -> Option<PDButtons>
Uses getButtonState.
Requests & returns only current part of state, see Self::current
sourcepub fn get_pushed() -> Option<PDButtons>
pub fn get_pushed() -> Option<PDButtons>
Uses getButtonState.
Requests & returns only current part of state, see Self::pushed
sourcepub fn get_released() -> Option<PDButtons>
pub fn get_released() -> Option<PDButtons>
Uses getButtonState.
Requests & returns only current part of state, see Self::released