pub struct Crank<Api = Default>(/* private fields */);
Crank

Implementations

source

impl Crank<Default>

source

pub fn Default() -> Self

Creates default Crank without type parameter requirement.

Uses ZST api::Default.

source

impl Crank<Cache>

source

pub fn Cached() -> Self

Creates Crank without type parameter requirement.

Uses api::Cache.

source

impl<Api: Default + Api> Crank<Api>

source

pub fn new() -> Self

source

impl<Api: Api> Crank<Api>

source

pub const fn new_with(api: Api) -> Self

source

impl<Api: Api> Crank<Api>

source

pub fn docked(&self) -> bool

Returns boolean indicating whether or not the crank is folded into the unit.

Equivalent to sys::ffi::playdate_sys::isCrankDocked.

source

pub fn angle(&self) -> c_float

Returns the current position of the crank, in the range 0-360. Zero is pointing up, and the value increases as the crank moves clockwise, as viewed from the right side of the device.

Equivalent to sys::ffi::playdate_sys::getCrankAngle.

source

pub fn change(&self) -> c_float

Returns the angle change of the crank since the last time this function was called. Negative values are anti-clockwise.

Equivalent to sys::ffi::playdate_sys::getCrankChange.

source

pub fn disable_sounds(&self, disable: bool) -> bool

Returns the previous value for this setting.

Equivalent to sys::ffi::playdate_sys::setCrankSoundsDisabled.